AndroidBannerAdType enum
自渲染Android banner广告大小枚举
Values
- AD_SIZE_W690xH388 → const AndroidBannerAdType
- AD_SIZE_W600xH400 → const AndroidBannerAdType
- AD_SIZE_W600xH300 → const AndroidBannerAdType
- AD_SIZE_W600xH260 → const AndroidBannerAdType
- AD_SIZE_W600xH260_L_TEXT_R_PICTURE → const AndroidBannerAdType
- AD_SIZE_W600xH150 → const AndroidBannerAdType
- AD_SIZE_W600xH150_L_TEXT_R_PICTURE → const AndroidBannerAdType
- AD_SIZE_W640xH100 → const AndroidBannerAdType
- AD_SIZE_W640xH100_L_TEXT_R_PICTURE → const AndroidBannerAdType
- AD_SIZE_W600xH90 → const AndroidBannerAdType
- AD_SIZE_W600xH90_L_TEXT_R_PICTURE → const AndroidBannerAdType
- AD_SIZE_W300xH200 → const AndroidBannerAdType
- AD_SIZE_W300xH200_BLACK → const AndroidBannerAdType
- AD_SIZE_W600xH540 → const AndroidBannerAdType
- AD_SIZE_W600xH540_TRANSPARENT → const AndroidBannerAdType
- AD_SIZE_W16H9_B52 → const AndroidBannerAdType
- AD_SIZE_W16H9_B34 → const AndroidBannerAdType
- AD_SIZE_W16H9 → const AndroidBannerAdType
- AD_SIZE_W600xH410 → const AndroidBannerAdType
- AD_SIZE_W640XH100 → const AndroidBannerAdType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AndroidBannerAdType> - A constant List of the values in this enum, in order of their declaration.