IOSBannerAdType enum
自渲染iOS banner广告大小枚举
Values
- AD_SIZE_W690xH388 → const IOSBannerAdType
- AD_SIZE_W600xH400 → const IOSBannerAdType
- AD_SIZE_W600xH300 → const IOSBannerAdType
- AD_SIZE_W600xH260 → const IOSBannerAdType
- AD_SIZE_W600xH260_L_TEXT_R_PICTURE → const IOSBannerAdType
- AD_SIZE_W600xH150 → const IOSBannerAdType
- AD_SIZE_W600xH150_L_TEXT_R_PICTURE → const IOSBannerAdType
- AD_SIZE_W640xH100 → const IOSBannerAdType
- AD_SIZE_W640xH100_L_TEXT_R_PICTURE → const IOSBannerAdType
- AD_SIZE_W600xH90 → const IOSBannerAdType
- AD_SIZE_W600xH90_L_TEXT_R_PICTURE → const IOSBannerAdType
- AD_SIZE_W300xH200_BLACK → const IOSBannerAdType
- AD_SIZE_W300xH200_WHITE → const IOSBannerAdType
- AD_SIZE_VERTICAL_TITLE_DESC_BELOW_IMAGE → const IOSBannerAdType
- AD_SIZE_VERTICAL_TITLE_BELOW_IMAGE → const IOSBannerAdType
- AD_SIZE_VERTICAL_TITLE_ON_BOTTOM → const IOSBannerAdType
- AD_SIZE_NEW_W600xH150_L_P_R_T → const IOSBannerAdType
- AD_SIZE_NEW_W600xH400_T_P_D_T → const IOSBannerAdType
- AD_SIZE_NEW_W600xH260_L_P_R_T → const IOSBannerAdType
- AD_SIZE_NEW_VER_TD_BP → const IOSBannerAdType
- AD_SIZE_NEW_H800 → const IOSBannerAdType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
IOSBannerAdType> - A constant List of the values in this enum, in order of their declaration.